@@ -313,7 +313,8 @@ class delhi_hc_search:
         li = soup.find_all('li', {"class": "clearfix odd"})
 
         orders = {}
-        for i in range(len(li)):
+        try:
+            for i in range(len(li)):
             """
             The Delhi High court website essentially has a a case status page and a button
             which gives details of all the orders related to that case. This function
@@ -338,7 +339,11 @@ class delhi_hc_search:
             orders[f'n_{i + 1}']['case_no'] = case_no
             orders[f'n_{i + 1}']['date_of_order'] = date_of_order
             orders[f'n_{i + 1}']['corrigendum'] = corrigendum
-        return orders
+            return orders
+
+        except:
+            return None
+
 
     def setup(self):
         options = Options()
